=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2006-01-03 02:43:17 +0000
+++ bzrlib/tests/test_transport.py	2006-01-03 03:00:07 +0000
@@ -800,20 +800,6 @@
         self.failUnless(t2.has('d'))
         self.failUnless(t3.has('b/d'))
 
-        
-class HttpTransportTest(TestCaseWithWebserver, TestTransportMixIn):
-
-    readonly = True
-
-    def get_transport(self):
-        from bzrlib.transport.http import HttpTransport
-        url = self.get_remote_url(u'.')
-        return HttpTransport(url)
-
-    def get_bogus_transport(self):
-        from bzrlib.transport.http import HttpTransport
-        return HttpTransport('http://jasldkjsalkdjalksjdkljasd')
-
 
 class MemoryTransportTest(TestCase):
     """Memory transport specific tests."""

=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2005-12-27 22:52:12 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-01-03 03:00:07 +0000
@@ -25,7 +25,7 @@
 
 from bzrlib.errors import (NoSuchFile, FileExists,
                            TransportNotPossible, ConnectionError)
-from bzrlib.tests import TestCase, TestCaseInTempDir
+from bzrlib.tests import TestCaseInTempDir, TestSkipped
 from bzrlib.transport import memory, urlescape
 import bzrlib.transport
 
@@ -541,9 +541,12 @@
 
     def test_connection_error(self):
         """ConnectionError is raised when connection is impossible"""
-        if not hasattr(self, "get_bogus_transport"):
-            return
-        t = self.get_bogus_transport()
+        try:
+            url = self._server.get_bogus_url()
+        except NotImplementedError:
+            raise TestSkipped("Transport %s has no bogus URL support." %
+                              self._server.__class__)
+        t = bzrlib.transport.get_transport(url)
         try:
             t.get('.bzr/branch')
         except (ConnectionError, NoSuchFile), e:
@@ -671,14 +674,6 @@
         self.assertEqual(transport.base + 'relpath',
                          transport.abspath('relpath'))
 
-###class HttpTransportTest(TestCaseWithWebserver):
-###
-###    readonly = True
-###
-###    def get_bogus_transport(self):
-###        from bzrlib.transport.http import HttpTransport
-###        return HttpTransport('http://jasldkjsalkdjalksjdkljasd')
-
     def test_iter_files_recursive(self):
         transport = self.get_transport()
         if not transport.listable():

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-01-03 02:43:17 +0000
+++ bzrlib/transport/__init__.py	2006-01-03 03:00:07 +0000
@@ -455,6 +455,10 @@
         """
         raise NotImplementedError
 
+    def get_bogus_url(self):
+        """Return a url for this protocol, that will fail to connect."""
+        raise NotImplementedError
+
 
 class TransportTestProviderAdapter(object):
     """A class which can setup transport interface tests."""

=== modified file 'bzrlib/transport/http.py'
--- bzrlib/transport/http.py	2006-01-03 02:07:06 +0000
+++ bzrlib/transport/http.py	2006-01-03 03:00:07 +0000
@@ -420,3 +420,8 @@
     def get_url(self):
         """See bzrlib.transport.Server.get_url."""
         return self._get_remote_url(self._home_dir)
+        
+    def get_bogus_url(self):
+        """See bzrlib.transport.Server.get_bogus_url."""
+        return 'http://jasldkjsalkdjalksjdkljasd'
+

